! -*- fortran -*-
!
! Copyright (c) 2018      FUJITSU LIMITED.  All rights reserved.
! $COPYRIGHT$
!
! Additional copyrights may follow
!
! $HEADER$
!

        integer MPIX_SHORT_FLOAT
        integer MPIX_C_SHORT_FLOAT_COMPLEX
        integer MPIX_CXX_SHORT_FLOAT_COMPLEX
        integer MPIX_C_FLOAT16

        parameter (MPIX_SHORT_FLOAT=74)
        parameter (MPIX_C_SHORT_FLOAT_COMPLEX=75)
        parameter (MPIX_CXX_SHORT_FLOAT_COMPLEX=76)
        parameter (MPIX_C_FLOAT16=74)
